/**
 * MIT License
 *
 * Copyright (c) 2017 Douglas Nassif Roma Junior
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
import { ViewStyle, StyleProp, TextStyle } from 'react-native';
import { DialogPropsType } from './Dialog';
declare type ConfirmDialogButtonPropsType = {
    title: string;
    onPress: () => void;
    disabled?: boolean;
    titleStyle?: StyleProp<TextStyle & {
        colorDisabled?: TextStyle['color'];
    }>;
    style?: StyleProp<ViewStyle & {
        backgroundColorDisabled?: ViewStyle['backgroundColor'];
    }>;
};
export declare type ConfirmDialogPropsType = DialogPropsType & {
    message?: string;
    messageStyle?: StyleProp<TextStyle>;
    negativeButton?: ConfirmDialogButtonPropsType;
    positiveButton: ConfirmDialogButtonPropsType;
};
declare const ConfirmDialog: {
    ({ children, negativeButton, positiveButton, message, messageStyle, ...others }: ConfirmDialogPropsType): JSX.Element;
    defaultProps: {
        visible: boolean;
        onRequestClose: () => null;
        contentInsetAdjustmentBehavior: string;
    };
};
export default ConfirmDialog;
